
## Update Chromedriver

Comprueba la versión actual del Google Chrome y descarga o actualiza el chromedriver.

*Únicamete para Linux y macos en esta versión 1.0

USO:
- Llamar a la clase y añadir el argumento con la ruta donde se ubica el chromedriver.
- Si es la primera vez que se usa, añadirá un nuevo archivo de info de versión para sus futuras comprobaciones.
- En caso de actualizar renombrará el archivo antiguo para no borrarlo.
- Por último se descargará la nueva versión si fuese necesario.

